@@ -1,12 +1,12 @@
+#include <stan/model/indexing.hpp>
+#include <stan/math/rev/fun/sum.hpp>
+#include <stan/math/prim/fun/eval.hpp>
+#include <test/unit/util.hpp>
+#include <test/unit/model/indexing/util.hpp>
+#include <gtest/gtest.h>
 #include <iostream>
 #include <stdexcept>
 #include <vector>
-#include <stan/model/indexing/rvalue.hpp>
-#include <stan/model/indexing/rvalue_varmat.hpp>
-#include <test/unit/util.hpp>
-#include <test/unit/model/indexing/util.hpp>
-#include <stan/math.hpp>
-#include <gtest/gtest.h>
 
 using stan::model::index_max;
 using stan::model::index_min;
@@ -415,9 +415,9 @@ TEST_F(RvalueRev, uni_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(4, 3);
+  auto x = conditionally_generate_linear_var_matrix(4, 3);
 
   var_value<Eigen::RowVectorXd> y = rvalue(x, "", index_uni(1));
   EXPECT_EQ(3, y.size());
@@ -434,7 +434,7 @@ TEST_F(RvalueRev, uni_mat) {
 }
 
 TEST_F(RvalueRev, uni_uni_mat) {
-  using stan::model::test::check_matrix_adjs;
+  using stan::model::test::check_adjs;
   Eigen::MatrixXd x_val(3, 4);
   x_val << 0.0, 0.1, 0.2, 0.3, 1.0, 1.1, 1.2, 1.3, 2.0, 2.1, 2.2, 2.3;
   for (int m = 0; m < 3; ++m) {
@@ -445,7 +445,7 @@ TEST_F(RvalueRev, uni_uni_mat) {
       x_sub.grad();
       auto check_i = [m](int i) { return m == i; };
       auto check_j = [n](int j) { return n == j; };
-      check_matrix_adjs(check_i, check_j, x);
+      check_adjs(check_i, check_j, x);
       stan::math::recover_memory();
     }
   }
@@ -462,9 +462,9 @@ TEST_F(RvalueRev, omni_uni_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::VectorXd> y = rvalue(x, "", index_omni(), index_uni(2));
   EXPECT_EQ(3, y.size());
   EXPECT_MATRIX_EQ(y.val(), x.val().col(1));
@@ -481,11 +481,11 @@ TEST_F(RvalueRev, omni_uni_mat) {
 TEST_F(RvalueRev, multi_uni_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::check_matrix_adjs;
-  using stan::model::test::generate_linear_var_matrix;
-  using stan::model::test::generate_linear_var_vector;
+  using stan::model::test::check_adjs;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_vector;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   std::vector<int> ns{3, 1, 1};
   var_value<Eigen::VectorXd> y = rvalue(x, "", index_multi(ns), index_uni(3));
   EXPECT_FLOAT_EQ(y.val()(0), x.val()(2, 2));
@@ -511,9 +511,9 @@ TEST_F(RvalueRev, min_uni_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::VectorXd> y = rvalue(x, "", index_min(2), index_uni(3));
   EXPECT_EQ(2, y.size());
   EXPECT_MATRIX_EQ(y.val(), x.val().col(2).segment(1, 2));
@@ -533,9 +533,9 @@ TEST_F(RvalueRev, min_uni_mat) {
 TEST_F(RvalueRev, minmax_uni_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::VectorXd> y
       = rvalue(x, "", index_min_max(2, 3), index_uni(4));
   EXPECT_MATRIX_EQ(y.val(), x.val().col(3).segment(1, 2));
@@ -553,9 +553,9 @@ TEST_F(RvalueRev, minmax_uni_matrix) {
 TEST_F(RvalueRev, negative_minmax_uni_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::VectorXd> y
       = rvalue(x, "", index_min_max(3, 2), index_uni(4));
   EXPECT_MATRIX_EQ(y.val(), x.val().col(3).segment(1, 2).reverse());
@@ -577,9 +577,9 @@ TEST_F(RvalueRev, multi_mat) {
   using Eigen::VectorXd;
   using stan::math::var_value;
 
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(4, 3);
+  auto x = conditionally_generate_linear_var_matrix(4, 3);
   std::vector<int> row_idx{3, 4, 1, 4, 1, 4, 1};
   var_value<Eigen::MatrixXd> y = rvalue(x, "", index_multi(row_idx));
   EXPECT_FLOAT_EQ(7, y.rows());
@@ -612,10 +612,10 @@ TEST_F(RvalueRev, multi_mat) {
 TEST_F(RvalueRev, uni_multi_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
-  using stan::model::test::generate_linear_var_vector;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_vector;
 
-  auto x = generate_linear_var_matrix(5, 5);
+  auto x = conditionally_generate_linear_var_matrix(5, 5);
   std::vector<int> ns{4, 1, 3, 3};
   var_value<Eigen::RowVectorXd> y
       = rvalue(x, "", index_uni(3), index_multi(ns));
@@ -682,10 +682,10 @@ TEST_F(RvalueRev, multi_multi_mat) {
 TEST_F(RvalueRev, minmax_multi_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
-  using stan::model::test::generate_linear_var_vector;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_vector;
 
-  auto x = generate_linear_var_matrix(5, 5);
+  auto x = conditionally_generate_linear_var_matrix(5, 5);
   std::vector<int> ns{4, 1, 3, 3};
   var_value<Eigen::MatrixXd> y
       = rvalue(x, "", index_min_max(1, 3), index_multi(ns));
@@ -715,9 +715,9 @@ TEST_F(RvalueRev, omni_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(4, 3);
+  auto x = conditionally_generate_linear_var_matrix(4, 3);
   var_value<Eigen::MatrixXd> y = rvalue(x, "", index_omni());
   EXPECT_EQ(4, y.rows());
   EXPECT_EQ(3, y.cols());
@@ -733,9 +733,9 @@ TEST_F(RvalueRev, uni_omni_mat) {
   using Eigen::RowVectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::RowVectorXd> y = rvalue(x, "", index_uni(2), index_omni());
   EXPECT_EQ(4, y.size());
   EXPECT_MATRIX_EQ(y.val(), x.val().row(1));
@@ -755,9 +755,9 @@ TEST_F(RvalueRev, omni_omni_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::MatrixXd> y = rvalue(x, "", index_omni(), index_omni());
   EXPECT_EQ(x.rows(), y.rows());
   EXPECT_EQ(x.cols(), y.cols());
@@ -775,9 +775,9 @@ TEST_F(RvalueRev, min_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(4, 3);
+  auto x = conditionally_generate_linear_var_matrix(4, 3);
   var_value<Eigen::MatrixXd> y = rvalue(x, "", index_min(3));
   EXPECT_EQ(2, y.rows());
   EXPECT_EQ(3, y.cols());
@@ -797,9 +797,9 @@ TEST_F(RvalueRev, uni_min_mat) {
   using Eigen::RowVectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::RowVectorXd> y = rvalue(x, "", index_uni(3), index_min(2));
   EXPECT_EQ(3, y.size());
   EXPECT_MATRIX_EQ(y.val(), x.val().row(2).segment(1, 3));
@@ -821,8 +821,8 @@ TEST_F(RvalueRev, min_min_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
-  auto x = generate_linear_var_matrix(3, 4);
+  using stan::model::test::conditionally_generate_linear_var_matrix;
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   stan::math::var_value<Eigen::MatrixXd> y
       = rvalue(x, "", index_min(2), index_min(3));
   EXPECT_EQ(2, y.rows());
@@ -843,9 +843,9 @@ TEST_F(RvalueRev, min_min_mat) {
 TEST_F(RvalueRev, minmax_min_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::MatrixXd> y
       = rvalue(x, "", index_min_max(2, 3), index_min(2));
   EXPECT_MATRIX_EQ(y.val(), x.val().block(1, 1, 2, 3));
@@ -868,9 +868,9 @@ TEST_F(RvalueRev, max_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(4, 3);
+  auto x = conditionally_generate_linear_var_matrix(4, 3);
   var_value<Eigen::MatrixXd> y = rvalue(x, "", index_max(2));
   EXPECT_EQ(2, y.rows());
   EXPECT_EQ(3, y.cols());
@@ -888,9 +888,9 @@ TEST_F(RvalueRev, max_mat) {
 TEST_F(RvalueRev, min_max_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::MatrixXd> y = rvalue(x, "", index_min(2), index_max(2));
   EXPECT_MATRIX_EQ(y.val(), x.val().block(1, 0, 2, 2));
   sum(y).grad();
@@ -912,9 +912,9 @@ TEST_F(RvalueRev, positive_min_max_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(4, 3);
+  auto x = conditionally_generate_linear_var_matrix(4, 3);
   var_value<Eigen::MatrixXd> y = rvalue(x, "", index_min_max(2, 3));
   EXPECT_EQ(2, y.rows());
   EXPECT_EQ(3, y.cols());
@@ -936,9 +936,9 @@ TEST_F(RvalueRev, negative_min_max_mat) {
   using Eigen::VectorXd;
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
 
-  auto x = generate_linear_var_matrix(3, 4);
+  auto x = conditionally_generate_linear_var_matrix(3, 4);
   var_value<Eigen::MatrixXd> y = rvalue(x, "", index_min_max(3, 2));
   EXPECT_EQ(2, y.rows());
   EXPECT_EQ(4, y.cols());
@@ -956,7 +956,7 @@ TEST_F(RvalueRev, negative_min_max_mat) {
 TEST_F(RvalueRev, positive_minmax_positive_minmax_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
   Eigen::MatrixXd x_val(5, 5);
   for (int i = 0; i < x_val.size(); ++i) {
     x_val(i) = i;
@@ -1058,10 +1058,10 @@ TEST_F(RvalueRev, negative_minmax_negative_minmax_matrix) {
 TEST_F(RvalueRev, uni_minmax_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
-  using stan::model::test::generate_linear_var_vector;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_vector;
 
-  auto x = generate_linear_var_matrix(5, 5);
+  auto x = conditionally_generate_linear_var_matrix(5, 5);
   var_value<Eigen::RowVectorXd> y
       = rvalue(x, "", index_uni(2), index_min_max(2, 4));
   EXPECT_MATRIX_EQ(y.val(), x.val().row(1).segment(1, 3));
@@ -1080,10 +1080,10 @@ TEST_F(RvalueRev, uni_minmax_matrix) {
 TEST_F(RvalueRev, uni_negative_minmax_matrix) {
   using stan::math::sum;
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
-  using stan::model::test::generate_linear_var_vector;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_vector;
 
-  auto x = generate_linear_var_matrix(5, 5);
+  auto x = conditionally_generate_linear_var_matrix(5, 5);
   var_value<Eigen::RowVectorXd> y
       = rvalue(x, "", index_uni(2), index_min_max(4, 2));
   EXPECT_MATRIX_EQ(y.val(), x.val().row(1).segment(1, 3).reverse());
@@ -1102,10 +1102,10 @@ TEST_F(RvalueRev, uni_negative_minmax_matrix) {
 // nil only shows up as a single index
 TEST_F(RvalueRev, nil_matrix) {
   using stan::math::var_value;
-  using stan::model::test::generate_linear_var_matrix;
-  using stan::model::test::generate_linear_var_vector;
+  using stan::model::test::conditionally_generate_linear_var_matrix;
+  using stan::model::test::conditionally_generate_linear_var_vector;
 
-  auto x = generate_linear_var_matrix(5, 5);
+  auto x = conditionally_generate_linear_var_matrix(5, 5);
   Eigen::MatrixXd x_val = x.val();
   auto y = rvalue(x, "");
   EXPECT_MATRIX_EQ(y.val(), x.val());
